@@ -632,16 +632,19 @@ liqcell *playground_create()
             
             
             
-            addone(self,body, "liqrecentsketches");
-            addone(self,body, "liqrecentphotos");
+            //addone(self,body, "liqrecentsketches");
+            // addone(self,body, "liqrecentphotos");
             addone(self,body, "liqcalendar");
-            addone(self,body, "liqaccelview_alternative");
-            addone(self,body, "liqflow");
+            if(liqapp_hardware_product_ispowerful_get())
+            {
+                addone(self,body, "liqaccelview_alternative");
+                addone(self,body, "liqflow");
+            }
             
             addone(self,body, "floatmap");
             
             addone(self,body, "onedotzero");
-            addone(self,body, "liqpostcard");
+           // addone(self,body, "liqpostcard");
             addone(self,body, "liqtorch");
             addone(self,body, "liqsketchedit");
         }
